pub struct OperationId(/* private fields */);Expand description
OperationId
Stable operation identifier shared by replay-protected commands. Owned by the replay model and serialized into stable replay receipts.
Implementations
Sourceimpl OperationId
impl OperationId
Sourcepub const fn from_bytes(bytes: [u8; 32]) -> Self
pub const fn from_bytes(bytes: [u8; 32]) -> Self
Build an operation id from its canonical 32-byte representation.
Sourcepub const fn as_bytes(&self) -> &[u8; 32]
pub const fn as_bytes(&self) -> &[u8; 32]
Return the canonical 32-byte operation id representation.
Sourcepub const fn into_bytes(self) -> [u8; 32]
pub const fn into_bytes(self) -> [u8; 32]
Consume the operation id and return its canonical bytes.