pub enum CanisterOpsMetricReason {
Show 15 variants
AlreadyExists,
Cycles,
InvalidState,
ManagementCall,
MissingWasm,
NewAllocation,
NotFound,
Ok,
PolicyDenied,
PoolReuse,
PoolTopup,
StatePropagation,
Topology,
TopologyPropagation,
Unknown,
}Expand description
CanisterOpsMetricReason
Bounded canister operation reason dimension used by public metrics projection.
Variants
AlreadyExists
Cycles
InvalidState
ManagementCall
MissingWasm
NewAllocation
NotFound
Ok
PolicyDenied
PoolReuse
PoolTopup
StatePropagation
Topology
TopologyPropagation
Unknown
Implementations
Sourceimpl CanisterOpsMetricReason
impl CanisterOpsMetricReason
Sourcepub const fn metric_label(self) -> &'static str
pub const fn metric_label(self) -> &'static str
Return the stable public metrics label for this reason.