pub struct LifecycleApi;Expand description
LifecycleApi
Implementations
Sourceimpl LifecycleApi
impl LifecycleApi
Sourcepub fn managed_binding() -> Result<ManagedCanisterBinding, Error>
pub fn managed_binding() -> Result<ManagedCanisterBinding, Error>
Return the immutable Registry-issued identity retained by this application Canister.
pub fn init_nonroot_canister_before_bootstrap( role: CanisterRole, payload: CanisterInitPayload, application_init_args: Option<Vec<u8>>, embedded_release_build_id: Option<&str>, authority: RoleRuntimeAuthority, )
Sourcepub fn init_nonroot_canister_with_fleet_admission_before_bootstrap(
role: CanisterRole,
payload: CanisterInitPayload,
application_init_args: Option<Vec<u8>>,
embedded_release_build_id: Option<&str>,
authority: RoleRuntimeAuthority,
)
pub fn init_nonroot_canister_with_fleet_admission_before_bootstrap( role: CanisterRole, payload: CanisterInitPayload, application_init_args: Option<Vec<u8>>, embedded_release_build_id: Option<&str>, authority: RoleRuntimeAuthority, )
Initialize a managed actor with its compile-selected admission store.
pub fn init_wasm_store_before_bootstrap( input: FleetSubnetWasmStoreInitArgs, embedded_release_build_id: Option<&str>, authority: RoleRuntimeAuthority, )
pub fn schedule_init_nonroot_bootstrap()
pub fn init_local_nonroot_canister_before_bootstrap( role: CanisterRole, env: EnvBootstrapArgs, authority: RoleRuntimeAuthority, )
pub fn post_upgrade_nonroot_canister_before_bootstrap( role: CanisterRole, embedded_release_build_id: Option<&str>, authority: RoleRuntimeAuthority, ) -> bool
Sourcepub fn post_upgrade_nonroot_canister_with_fleet_admission_before_bootstrap(
role: CanisterRole,
embedded_release_build_id: Option<&str>,
authority: RoleRuntimeAuthority,
) -> bool
pub fn post_upgrade_nonroot_canister_with_fleet_admission_before_bootstrap( role: CanisterRole, embedded_release_build_id: Option<&str>, authority: RoleRuntimeAuthority, ) -> bool
Restore selected admission before runtime services and lifecycle participants.
Sourcepub fn post_upgrade_nonroot_canister_with_automatic_topup_and_fleet_admission_before_bootstrap(
role: CanisterRole,
embedded_release_build_id: Option<&str>,
authority: RoleRuntimeAuthority,
) -> bool
pub fn post_upgrade_nonroot_canister_with_automatic_topup_and_fleet_admission_before_bootstrap( role: CanisterRole, embedded_release_build_id: Option<&str>, authority: RoleRuntimeAuthority, ) -> bool
Restore selected admission before runtime services and lifecycle participants.
pub fn schedule_post_upgrade_nonroot_bootstrap()
pub fn post_upgrade_local_nonroot_canister_before_bootstrap( role: CanisterRole, authority: RoleRuntimeAuthority, ) -> bool