ApprovedModuleSource

Struct ApprovedModuleSource 

pub struct ApprovedModuleSource { /* private fields */ }
ApprovedModuleSource

Implementations

Source

impl ApprovedModuleSource

pub const fn chunked( source_canister: Principal, source_label: String, module_hash: Vec<u8>, chunk_hashes: Vec<Vec<u8>>, payload_size_bytes: u64, ) -> Self

Construct one chunk-store-backed module source.

pub fn embedded(source_label: String, wasm_module: &'static [u8]) -> Self

Construct one embedded module source from already packaged wasm bytes.

pub fn source_label(&self) -> &str

Return the logical source label used for logs and status output.

pub fn module_hash(&self) -> &[u8]

Return the installable wasm module hash.

pub fn payload_size(&self) -> String

Return the formatted module payload size for logs and status output.

pub const fn payload_size_bytes(&self) -> u64

Return the raw payload size in bytes.

pub const fn chunk_count(&self) -> usize

Return the chunk count when the source is chunk-store-backed.

pub const fn payload(&self) -> &ApprovedModulePayload

Return the underlying payload representation.