RuntimeIntrospectionApi

Struct RuntimeIntrospectionApi 

pub struct RuntimeIntrospectionApi;
RuntimeIntrospectionApi

Implementations

Source

impl RuntimeIntrospectionApi

pub fn record_recent_failure( occurred_at_ns: u64, subsystem: impl Into<String>, code: impl Into<String>, severity: FailureSeverity, summary: impl Into<String>, correlation_id: Option<String>, )

Record one heap-only recent-failure summary for guarded runtime status.

pub fn health(observed_at_ns: Option<u64>) -> CanicHealthStatus

Return the minimal health status for a canister that answered the query.

pub fn readiness(observed_at_ns: u64) -> CanicReadinessStatus

Return guarded readiness status for the local Canic role.

pub fn runtime_status_for( canister_id: Principal, observed_at_ns: u64, package_name: &str, package_version: &str, canic_version: &str, canister_version: u64, ) -> CanicRuntimeStatus

Return guarded runtime status for the local Canic role.

pub fn runtime_status( observed_at_ns: u64, package_name: &str, package_version: &str, canic_version: &str, canister_version: u64, ) -> CanicRuntimeStatus

Return guarded runtime status using ambient IC runtime values.