pub struct CanicStandardsApi;Expand description
CanicStandardsApi
Implementations
Sourceimpl CanicStandardsApi
impl CanicStandardsApi
Sourcepub fn metadata() -> CanicStandardsResponse
pub fn metadata() -> CanicStandardsResponse
Return standards metadata for the core crate fallback path.
Sourcepub fn metadata_for(
name: &str,
version: &str,
description: &str,
) -> CanicStandardsResponse
pub fn metadata_for( name: &str, version: &str, description: &str, ) -> CanicStandardsResponse
Return standards metadata for the canister crate that exports the endpoint.