spawn

Function spawn 

pub fn spawn<F>(future: F)
where F: 'static + Future<Output = ()>,
Spawn a protected asynchronous task to run during the current canister method.

The task will panic if it outlives the canister method. To cancel it instead, use spawn_weak.