Module btreeset

Module btreeset 

This module implements a set based on a B-Tree in stable memory.

Structs

BTreeSet
A B-Tree set implementation that stores its data into a designated memory.
Iter
An iterator over the entries of a BTreeSet.