Module pool

Module pool 

Pool admin DTOs.

This module defines the command and response types used at the boundary of the pool workflow (endpoints, admin APIs).

These types:

  • are pure data
  • contain no logic
  • are safe to serialize / expose

They must NOT:

  • perform validation
  • call ops or workflow
  • embed policy or orchestration logic

Structs

CanisterPoolEntry
CanisterPoolResponse
CreateEmptyPoolRequest
PoolBatchResult

Enums

CanisterPoolStatus
CanisterPoolStatus
PoolAdminCommand
PoolAdminResponse