pub struct ComponentGroupPlacementId {
pub deployment: ComponentGroupDeploymentId,
pub ordinal: u32,
}Expand description
Durable Fleet-scoped identity of one materialized Component Group deployment copy.
Fields
deployment: ComponentGroupDeploymentIdordinal: u32Trait Implementations
Sourceimpl Clone for ComponentGroupPlacementId
impl Clone for ComponentGroupPlacementId
Sourcefn clone(&self) -> ComponentGroupPlacementId
fn clone(&self) -> ComponentGroupPlacementId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComponentGroupPlacementId
impl Debug for ComponentGroupPlacementId
Sourceimpl<'de> Deserialize<'de> for ComponentGroupPlacementId
impl<'de> Deserialize<'de> for ComponentGroupPlacementId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ComponentGroupPlacementId
Sourceimpl Hash for ComponentGroupPlacementId
impl Hash for ComponentGroupPlacementId
Sourceimpl Ord for ComponentGroupPlacementId
impl Ord for ComponentGroupPlacementId
Sourcefn cmp(&self, other: &ComponentGroupPlacementId) -> Ordering
fn cmp(&self, other: &ComponentGroupPlacementId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ComponentGroupPlacementId
impl PartialOrd for ComponentGroupPlacementId
Sourceimpl Storable for ComponentGroupPlacementId
impl Storable for ComponentGroupPlacementId
Sourcefn to_bytes(&self) -> Cow<'_, [u8]>
fn to_bytes(&self) -> Cow<'_, [u8]>
Converts the element into a possibly borrowed byte slice. Read more
Sourcefn from_bytes(bytes: Cow<'_, [u8]>) -> Self
fn from_bytes(bytes: Cow<'_, [u8]>) -> Self
Converts bytes into an element.
Sourcefn to_bytes_checked(&self) -> Cow<'_, [u8]>
fn to_bytes_checked(&self) -> Cow<'_, [u8]>
Like
to_bytes, but checks that bytes conform to declared bounds.Sourcefn into_bytes_checked(self) -> Vec<u8> ⓘwhere
Self: Sized,
fn into_bytes_checked(self) -> Vec<u8> ⓘwhere
Self: Sized,
Like
into_bytes, but checks that bytes conform to declared bounds.Sourcefn check_bounds(bytes: &[u8])
fn check_bounds(bytes: &[u8])
Validates that a byte slice fits within this type’s declared bounds.
impl StructuralPartialEq for ComponentGroupPlacementId