pub struct MemoryRuntimeApi;Expand description
MemoryRuntimeApi
High-level runtime bootstrap facade used by the supported public API.
Implementations
Sourceimpl MemoryRuntimeApi
impl MemoryRuntimeApi
Sourcepub fn bootstrap_registry(
crate_name: &'static str,
start: u8,
end: u8,
) -> Result<MemoryRegistryInitSummary, MemoryRegistryError>
pub fn bootstrap_registry( crate_name: &'static str, start: u8, end: u8, ) -> Result<MemoryRegistryInitSummary, MemoryRegistryError>
Bootstrap eager-init hooks, the memory registry, and eager TLS for the given owner range.
Sourcepub fn bootstrap_registry_without_range() -> Result<MemoryRegistryInitSummary, MemoryRegistryError>
pub fn bootstrap_registry_without_range() -> Result<MemoryRegistryInitSummary, MemoryRegistryError>
Bootstrap eager-init hooks, flush deferred registry state, and then initialize eager TLS without reserving a new owner range.