pub fn command_endpoint_for_role(role: &CanisterRole) -> &'static strExpand description
Return the exact command endpoint owned by one Canic role.
pub fn command_endpoint_for_role(role: &CanisterRole) -> &'static strReturn the exact command endpoint owned by one Canic role.