AuthApi

Struct AuthApi 

pub struct AuthApi;
AuthApi

Owns delegated-token helpers and root-signed role-attestation helpers.

Implementations

Source

impl AuthApi

pub fn set_delegated_session_subject( delegated_subject: Principal, bootstrap_token: DelegatedToken, requested_ttl_secs: Option<u64>, ) -> Result<(), Error>

Persist a temporary delegated session subject for the caller wallet.

pub fn clear_delegated_session()

Remove the caller’s delegated session subject.

pub fn delegated_session_subject() -> Option<Principal>

Read the caller’s active delegated session subject, if configured.

pub fn prune_expired_delegated_sessions() -> usize

Prune all currently expired delegated sessions.

Source

impl AuthApi

pub fn prepare_delegated_token( request: DelegatedTokenPrepareRequest, ) -> Result<DelegatedTokenPrepareResponse, Error>

Prepare a delegated token from the issuer-local active delegation proof.

pub fn get_delegated_token( request: DelegatedTokenGetRequest, ) -> Result<DelegatedToken, Error>

Retrieve a prepared delegated token with its issuer canister-signature proof.

pub fn install_active_delegation_proof( request: InstallActiveDelegationProofRequest, ) -> Result<InstallActiveDelegationProofResponse, Error>

Install validated root-certified delegation material for issuer-local token issuance.

pub async fn prepare_delegation_proof( request: DelegationProofIssueRequest, ) -> Result<DelegationProofPrepareResponse, Error>

Prepare a root delegation proof from root over RPC.

pub fn prepare_delegation_proof_root( request: DelegationProofIssueRequest, ) -> Result<DelegationProofPrepareResponse, Error>

Prepare a root-certified delegation proof from the local root update path.

pub fn get_delegation_proof_root( request: DelegationProofGetRequest, ) -> Result<DelegationProof, Error>

Retrieve a prepared self-contained delegation proof from the local root query path.

pub fn prepare_role_attestation_root( request: RoleAttestationRequest, ) -> Result<RoleAttestationPrepareResponse, Error>

Prepare a root-certified role attestation from the local root update path.

pub fn get_role_attestation_root( request: RoleAttestationGetRequest, ) -> Result<SignedRoleAttestation, Error>

Retrieve a prepared role attestation with its root canister-signature proof.

pub async fn verify_role_attestation( attestation: &SignedRoleAttestation, min_accepted_epoch: u64, ) -> Result<(), Error>

Verify a role attestation locally from its embedded root proof.