Module: api::intent
Responsibility: expose direct local and receipt-backed intent operations. Does not own: external calls, domain receipt validation, or retry policy. Boundary: maps public inputs to non-awaiting intent workflows.
Re-exports
pub use crate::ids::IntentId;pub use crate::ids::IntentResourceKey;
Structs
- Begin
Local Intent Input - Complete input for beginning one locally decidable, expirable intent.
- Begin
Receipt Backed Intent Input - Complete input for idempotently beginning or loading one reservation.
- Local
Intent Api - Direct operations for locally decidable, expirable reservations.
- Operation
Id - OperationId
- Payload
Binding - Opaque, versioned binding for every field that changes an external effect.
- Receipt
Backed Intent - Read-only projection of one receipt-backed intent.
- Receipt
Backed Intent Api - Exact-key receipt-backed operations for consumer-validated evidence.
- Settle
Receipt Backed Intent Input - Complete input for compare-and-set terminal settlement.
- Terminal
Evidence - Bounded proof reference validated by the domain owner before settlement.
Enums
- Begin
Receipt Backed Intent Result - Idempotent outcome of receipt-backed begin-or-load.
- Receipt
Backed Intent State - Durable lifecycle of one receipt-backed intent.
- Settle
Receipt Backed Intent Result - Outcome of receipt-backed compare-and-set settlement.
- Terminal
Evidence Decision - Consumer-validated terminal decision for one receipt-backed reservation.