Skip to main contentModule structures
Source - btreeset
- This module implements a set based on a B-Tree in stable memory.
- cell
- A serializable value stored in the stable memory.
- file_mem
- log
- An append-only list data structure, also known as log.
- memory
- min_heap
- reader
- storable
- vec
- This module implements a growable array in stable memory.
- vec_mem
- writer
- BTreeSet
- A B-Tree set implementation that stores its data into a designated memory.
- Cell
- Represents a value stored in stable memory.
- FileMemory
- A
Memory backed by a file. - Log
- Append-only list of variable-size entries stored in stable memory.
- MinHeap
- An implementation of the binary min heap.
- StableBTreeSet
- A B-Tree set implementation that stores its data into a designated memory.
- StableCell
- Represents a value stored in stable memory.
- StableLog
- Append-only list of variable-size entries stored in stable memory.
- StableMinHeap
- An implementation of the binary min heap.
- StableVec
- An implementation of growable arrays in stable memory.
- Vec
- An implementation of growable arrays in stable memory.
- Memory
- Abstraction over a WebAssembly-style linear memory (e.g., stable memory).
- Storable
- A trait with convenience methods for storing an element into a stable structure.
- DefaultMemoryImpl
- VectorMemory
- A
Memory that is based on a vector.